==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/et.php <==
<?php

return [
    'Names' => [
        'Afak' => 'afaka',
        'Aghb' => 'albaani',
        'Ahom' => 'ahomi',
        'Arab' => 'araabia',
        'Aran' => 'nastaliik',
        'Armi' => 'vanaaramea',
        'Armn' => 'armeenia',
        'Avst' => 'avesta',
        'Bali' => 'bali',
        'Bamu' => 'bamumi',
        'Bass' => 'bassa',
        'Batk' => 'bataki',
        'Beng' => 'bengali',
        'Blis' => 'Blissi sümbolid',
        'Bopo' => 'bopomofo',
        'Brah' => 'braahmi',
        'Brai' => 'punktkiri',
        'Bugi' => 'bugi',
        'Buhd' => 'buhidi',
        'Cakm' => 'tšaakma',
        'Cans' => 'Kanada põlisrahvaste ühtlustatud silpkiri',
        'Cari' => 'kaaria',
        'Cham' => 'tšaami',
        'Cher' => 'tšerokii',
        'Chrs' => 'horezmi',
        'Cirt' => 'Cirthi',
        'Copt' => 'kopti',
        'Cpmn' => 'Küprose minose',
        'Cprt' => 'Küprose silpkiri',
        'Cyrl' => 'kirillitsa',
        'Cyrs' => 'kürilliline kirikuslaavi',
        'Deva' => 'devanaagari',
        'Diak' => 'divehi',
        'Dsrt' => 'desereti',
        'Dupl' => 'Duployé kiirkiri',
        'Egyd' => 'egiptuse demootiline',
        'Egyh' => 'egiptuse hieraatiline',
        'Egyp' => 'egiptuse hieroglüüfkiri',
        'Elba' => 'Elbasani',
        'Ethi' => 'etioopia',
        'Geok' => 'hutsuri',
        'Geor' => 'gruusia',
        'Glag' => 'glagoolitsa',
        'Gong' => 'Gūnjāla gondi',
        'Gonm' => 'Masarami gondi',
        'Goth' => 'gooti',
        'Gran' => 'grantha',
        'Grek' => 'kreeka',
        'Gujr' => 'gudžarati',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanbi',
        'Hang' => 'korea',
        'Hani' => 'hani',
        'Hano' => 'hanunoo',
        'Hans' => 'lihtsustatud',
        'Hant' => 'traditsiooniline',
        'Hatr' => 'Hatra',
        'Hebr' => 'heebrea',
        'Hira' => 'hiragana',
        'Hluw' => 'Anatoolia hieroglüüfkiri',
        'Hmng' => 'phahau-hmongi kiri',
        'Hrkt' => 'jaapani silpkirjad',
        'Hung' => 'vanaungari',
        'Inds' => 'Induse',
        'Ital' => 'vanaitali',
        'Jamo' => 'jamo',
        'Java' => 'jaava',
        'Jpan' => 'jaapani',
        'Jurc' => 'tšurtšeni',
        'Kali' => 'kaja-lii',
        'Kana' => 'katakana',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmeeri',
        'Khoj' => 'hodžki',
        'Kits' => 'kitani väike kiri',
        'Knda' => 'kannada',
        'Kore' => 'korea segakiri',
        'Kpel' => 'kpelle',
        'Kthi' => 'kaithi',
        'Lana' => 'tai-thami',
        'Laoo' => 'lao',
        'Latf' => 'ladina fraktuurkiri',
        'Latg' => 'ladina gaeli',
        'Latn' => 'ladina',
        'Lepc' => 'leptša',
        'Limb' => 'limbu',
        'Lina' => 'lineaarkiri A',
        'Linb' => 'lineaarkiri B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lüükia',
        'Lydi' => 'lüüdia',
        'Mahj' => 'mahaadžani',
        'Maka' => 'makassari',
        'Mand' => 'mandea',
        'Mani' => 'mani',
        'Maya' => 'maaja hieroglüüfkiri',
        'Mend' => 'mende',
        'Merc' => 'meroe kursiivkiri',
        'Mero' => 'meroe',
        'Mlym' => 'malajalami',
        'Modi' => 'modi',
        'Mong' => 'mongoli',
        'Moon' => 'Mooni',
        'Mroo' => 'mruu',
        'Mtei' => 'meitei',
        'Mult' => 'Multani',
        'Mymr' => 'birma',
        'Narb' => 'Põhja-Araabia',
        'Nbat' => 'Nabatea',
        'Newa' => 'nevari',
        'Nkgb' => 'nasi',
        'Nkoo' => 'nkoo',
        'Nshu' => 'nüšu',
        'Ogam' => 'ogam',
        'Olck' => 'santali',
        'Orkh' => 'Orhoni',
        'Orya' => 'oria',
        'Osge' => 'oseidži',
        'Osma' => 'osmani',
        'Ougr' => 'vanauiguuri',
        'Palm' => 'Palmyra',
        'Perm' => 'vanapermi',
        'Phag' => 'phakpa',
        'Phli' => 'pahlavi raidkiri',
        'Phlp' => 'pahlavi psalmikiri',
        'Phlv' => 'pahlavi raamatukiri',
        'Phnx' => 'foiniikia',
        'Plrd' => 'Pollardi miao',
        'Prti' => 'partia raidkiri',
        'Rjng' => 'redžangi',
        'Rohg' => 'rohingja',
        'Roro' => 'rongorongo',
        'Runr' => 'ruunikiri',
        'Samr' => 'Samaaria',
        'Sara' => 'sarati',
        'Sarb' => 'Lõuna-Araabia',
        'Saur' => 'sauraštra',
        'Sgnw' => 'viipekiri',
        'Shaw' => 'Shaw’ kiri',
        'Shrd' => 'šaarada',
        'Sidd' => 'siddhami',
        'Sind' => 'hudavadi',
        'Sinh' => 'singali',
        'Sogd' => 'sogdi',
        'Sogo' => 'vanasogdi',
        'Sora' => 'sora',
        'Soyo' => 'sojombo',
        'Sund' => 'sunda',
        'Sylo' => 'siloti',
        'Syrc' => 'süüria',
        'Syre' => 'süüria estrangelo',
        'Syrj' => 'läänesüüria',
        'Syrn' => 'idasüüria',
        'Tagb' => 'tagbanva',
        'Takr' => 'taakri',
        'Tale' => 'tai-löö',
        'Talu' => 'uus tai-lõõ',
        'Taml' => 'tamili',
        'Tang' => 'tanguudi',
        'Tavt' => 'tai-vieti',
        'Telu' => 'telugu',
        'Teng' => 'Tengwari',
        'Tfng' => 'tifinagi',
        'Tglg' => 'tagalogi',
        'Thaa' => 'taana',
        'Thai' => 'tai',
        'Tibt' => 'tiibeti',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tase',
        'Toto' => 'toto',
        'Ugar' => 'ugariti',
        'Vaii' => 'vai',
        'Visp' => 'nähtava kõne',
        'Vith' => 'Vithkuqi',
        'Wara' => 'hoo',
        'Wcho' => 'vantšo',
        'Wole' => 'voleai',
        'Xpeo' => 'vanapärsia',
        'Xsux' => 'sumeri-akadi kiilkiri',
        'Yiii' => 'jii',
        'Zanb' => 'Dzanabadzari ruutkiri',
        'Zinh' => 'päritud',
        'Zmth' => 'matemaatiline tähistus',
        'Zsye' => 'emoji',
        'Zsym' => 'sümbolid',
        'Zxxx' => 'kirjakeeleta',
        'Zyyy' => 'üldine',
    ],
];

==> symfony_7.4.2+dfsg.orig.tar.xz: symfony-7.4.2/src/Symfony/Component/Intl/Resources/data/scripts/et.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'adlami',
        'Afak' => 'afaka',
        'Aghb' => 'albaani',
        'Ahom' => 'ahomi',
        'Arab' => 'araabia',
        'Aran' => 'nastaliik',
        'Armi' => 'vanaaramea',
        'Armn' => 'armeenia',
        'Avst' => 'avesta',
        'Bali' => 'bali',
        'Bamu' => 'bamumi',
        'Bass' => 'bassa',
        'Batk' => 'bataki',
        'Beng' => 'bengali',
        'Berf' => 'zaghava',
        'Bhks' => 'bhaiksuki',
        'Blis' => 'Blissi sümbolid',
        'Bopo' => 'bopomofo',
        'Brah' => 'braahmi',
        'Brai' => 'punktkiri',
        'Bugi' => 'bugi',
        'Buhd' => 'buhidi',
        'Cakm' => 'tšaakma',
        'Cans' => 'Kanada põlisrahvaste ühtlustatud silpkiri',
        'Cari' => 'kaaria',
        'Cham' => 'tšaami',
        'Cher' => 'tšerokii',
        'Chrs' => 'horezmi',
        'Cirt' => 'Cirthi',
        'Copt' => 'kopti',
        'Cpmn' => 'Küprose minose',
        'Cprt' => 'Küprose silpkiri',
        'Cyrl' => 'kirillitsa',
        'Cyrs' => 'kürilliline kirikuslaavi',
        'Deva' => 'devanaagari',
        'Diak' => 'divehi',
        'Dogr' => 'dogri',
        'Dsrt' => 'desereti',
        'Dupl' => 'Duployé kiirkiri',
        'Egyd' => 'egiptuse demootiline',
        'Egyh' => 'egiptuse hieraatiline',
        'Egyp' => 'egiptuse hieroglüüfkiri',
        'Elba' => 'Elbasani',
        'Elym' => 'elümi',
        'Ethi' => 'etioopia',
        'Gara' => 'garai',
        'Geok' => 'hutsuri',
        'Geor' => 'gruusia',
        'Glag' => 'glagoolitsa',
        'Gong' => 'Gūnjāla gondi',
        'Gonm' => 'Masarami gondi',
        'Goth' => 'gooti',
        'Gran' => 'grantha',
        'Grek' => 'kreeka',
        'Gujr' => 'gudžarati',
        'Gukh' => 'gurungi',
        'Guru' => 'gurmukhi',
        'Hanb' => 'hanbi',
        'Hang' => 'korea',
        'Hani' => 'hani',
        'Hano' => 'hanunoo',
        'Hans' => 'lihtsustatud',
        'Hant' => 'traditsiooniline',
        'Hatr' => 'Hatra',
        'Hebr' => 'heebrea',
        'Hira' => 'hiragana',
        'Hluw' => 'Anatoolia hieroglüüfkiri',
        'Hmng' => 'phahau-hmongi kiri',
        'Hmnp' => 'Chervangi kiri',
        'Hrkt' => 'jaapani silpkirjad',
        'Hung' => 'vanaungari',
        'Inds' => 'Induse',
        'Ital' => 'vanaitali',
        'Jamo' => 'jamo',
        'Java' => 'jaava',
        'Jpan' => 'jaapani',
        'Jurc' => 'tšurtšeni',
        'Kali' => 'kaja-lii',
        'Kana' => 'katakana',
        'Kawi' => 'kaavi',
        'Khar' => 'kharoshthi',
        'Khmr' => 'khmeeri',
        'Khoj' => 'hodžki',
        'Kits' => 'kitani väike kiri',
        'Knda' => 'kannada',
        'Kore' => 'korea segakiri',
        'Kpel' => 'kpelle',
        'Krai' => 'kirat-rai',
        'Kthi' => 'kaithi',
        'Lana' => 'tai-thami',
        'Laoo' => 'lao',
        'Latf' => 'ladina fraktuurkiri',
        'Latg' => 'ladina gaeli',
        'Latn' => 'ladina',
        'Lepc' => 'leptša',
        'Limb' => 'limbu',
        'Lina' => 'lineaarkiri A',
        'Linb' => 'lineaarkiri B',
        'Lisu' => 'lisu',
        'Loma' => 'loma',
        'Lyci' => 'lüükia',
        'Lydi' => 'lüüdia',
        'Mahj' => 'mahaadžani',
        'Maka' => 'makassari',
        'Mand' => 'mandea',
        'Mani' => 'mani',
        'Marc' => 'martšeni',
        'Maya' => 'maaja hieroglüüfkiri',
        'Medf' => 'medefaidrini',
        'Mend' => 'mende',
        'Merc' => 'meroe kursiivkiri',
        'Mero' => 'meroe',
        'Mlym' => 'malajalami',
        'Modi' => 'modi',
        'Mong' => 'mongoli',
        'Moon' => 'Mooni',
        'Mroo' => 'mruu',
        'Mtei' => 'meitei',
        'Mult' => 'Multani',
        'Mymr' => 'birma',
        'Nagm' => 'Nagi mundari',
        'Nand' => 'nandinaagari',
        'Narb' => 'Põhja-Araabia',
        'Nbat' => 'Nabatea',
        'Newa' => 'nevari',
        'Nkgb' => 'nasi',
        'Nkoo' => 'nkoo',
        'Nshu' => 'nüšu',
        'Ogam' => 'ogam',
        'Olck' => 'santali',
        'Onao' => 'bhumidži',
        'Orkh' => 'Orhoni',
        'Orya' => 'oria',
        'Osge' => 'oseidži',
        'Osma' => 'osmani',
        'Ougr' => 'vanauiguuri',
        'Palm' => 'Palmyra',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'vanapermi',
        'Phag' => 'phakpa',
        'Phli' => 'pahlavi raidkiri',
        'Phlp' => 'pahlavi psalmikiri',
        'Phlv' => 'pahlavi raamatukiri',
        'Phnx' => 'foiniikia',
        'Plrd' => 'Pollardi miao',
        'Prti' => 'partia raidkiri',
        'Rjng' => 'redžangi',
        'Rohg' => 'rohingja',
        'Roro' => 'rongorongo',
        'Runr' => 'ruunikiri',
        'Samr' => 'Samaaria',
        'Sara' => 'sarati',
        'Sarb' => 'Lõuna-Araabia',
        'Saur' => 'sauraštra',
        'Sgnw' => 'viipekiri',
        'Shaw' => 'Shaw’ kiri',
        'Shrd' => 'šaarada',
        'Sidd' => 'siddhami',
        'Sidt' => 'side',
        'Sind' => 'hudavadi',
        'Sinh' => 'singali',
        'Sogd' => 'sogdi',
        'Sogo' => 'vanasogdi',
        'Sora' => 'sora',
        'Soyo' => 'sojombo',
        'Sund' => 'sunda',
        'Sunu' => 'sunvari',
        'Sylo' => 'siloti',
        'Syrc' => 'süüria',
        'Syre' => 'süüria estrangelo',
        'Syrj' => 'läänesüüria',
        'Syrn' => 'idasüüria',
        'Tagb' => 'tagbanva',
        'Takr' => 'taakri',
        'Tale' => 'tai-löö',
        'Talu' => 'uus tai-lõõ',
        'Taml' => 'tamili',
        'Tang' => 'tanguudi',
        'Tavt' => 'tai-vieti',
        'Tayo' => 'njoo',
        'Telu' => 'telugu',
        'Teng' => 'Tengwari',
        'Tfng' => 'tifinagi',
        'Tglg' => 'tagalogi',
        'Thaa' => 'taana',
        'Thai' => 'tai',
        'Tibt' => 'tiibeti',
        'Tirh' => 'tirhuta',
        'Tnsa' => 'tase',
        'Todr' => 'Todhri',
        'Tols' => 'tolong-siki',
        'Toto' => 'toto',
        'Tutg' => 'tulu',
        'Ugar' => 'ugariti',
        'Vaii' => 'vai',
        'Visp' => 'nähtava kõne',
        'Vith' => 'Vithkuqi',
        'Wara' => 'hoo',
        'Wcho' => 'vantšo',
        'Wole' => 'voleai',
        'Xpeo' => 'vanapärsia',
        'Xsux' => 'sumeri-akadi kiilkiri',
        'Yezi' => 'jeziidi',
        'Yiii' => 'jii',
        'Zanb' => 'Dzanabadzari ruutkiri',
        'Zinh' => 'päritud',
        'Zmth' => 'matemaatiline tähistus',
        'Zsye' => 'emoji',
        'Zsym' => 'sümbolid',
        'Zxxx' => 'kirjakeeleta',
        'Zyyy' => 'üldine',
    ],
];
